summaryrefslogtreecommitdiff
path: root/usr.bin/ssh/ssh.h
diff options
context:
space:
mode:
Diffstat (limited to 'usr.bin/ssh/ssh.h')
-rw-r--r--usr.bin/ssh/ssh.h15
1 files changed, 10 insertions, 5 deletions
diff --git a/usr.bin/ssh/ssh.h b/usr.bin/ssh/ssh.h
index d63369e8125..e35c411c0e3 100644
--- a/usr.bin/ssh/ssh.h
+++ b/usr.bin/ssh/ssh.h
@@ -13,7 +13,7 @@
*
*/
-/* RCSID("$Id: ssh.h,v 1.31 1999/12/12 19:20:03 markus Exp $"); */
+/* RCSID("$Id: ssh.h,v 1.32 2000/01/04 00:08:00 markus Exp $"); */
#ifndef SSH_H
#define SSH_H
@@ -261,7 +261,7 @@ get_last_login_time(uid_t uid, const char *logname,
*/
void
record_login(int pid, const char *ttyname, const char *user, uid_t uid,
- const char *host, struct sockaddr_in * addr);
+ const char *host, struct sockaddr *addr);
/*
* Records that the user has logged out. This does many thigs normally done
@@ -281,7 +281,7 @@ void record_logout(int pid, const char *ttyname);
* packet_set_connection for the connection.
*/
int
-ssh_connect(const char *host, struct sockaddr_in * hostaddr,
+ssh_connect(const char *host, struct sockaddr_storage * hostaddr,
u_short port, int connection_attempts,
int anonymous, uid_t original_real_uid,
const char *proxy_command);
@@ -297,7 +297,7 @@ ssh_connect(const char *host, struct sockaddr_in * hostaddr,
void
ssh_login(int host_key_valid, RSA * host_key, const char *host,
- struct sockaddr_in * hostaddr, uid_t original_real_uid);
+ struct sockaddr * hostaddr, uid_t original_real_uid);
/*------------ Definitions for various authentication methods. -------*/
@@ -357,8 +357,10 @@ const char *get_remote_ipaddr(void);
/* Returns the port number of the peer of the socket. */
int get_peer_port(int sock);
/* Returns the port number of the remote host. */
int get_remote_port(void);
+int get_local_port(void);
+
/*
* Tries to match the host name (which must be in all lowercase) against the
@@ -718,4 +720,7 @@ char *skey_fake_keyinfo(char *username);
int auth_skey_password(struct passwd * pw, const char *password);
#endif /* SKEY */
+/* AF_UNSPEC or AF_INET or AF_INET6 */
+extern int IPv4or6;
+
#endif /* SSH_H */
@@ -357,8 +357,10 @@ const char *get_remote_ipaddr(void);
/* Returns the port number of the peer of the socket. */
int get_peer_port(int sock);
-/* Returns the port number of the remote host. */
+/* Returns the port number of the remote/local host. */
int get_remote_port(void);